@@ -8,4 +8,4 @@ __author__ = "mxngo"
 __copyright__ = ":copyright: (c) 2023-present mxngo"
 __license__ = "MIT"
 
-from .private_modifier import private
\ No newline at end of file
+from ._private_modifier import private
\ No newline at end of file
